@@ -16,13 +16,19 @@ inline double myrunif(){return unif_rand();}
 //' @param w a vector of weights
 //' @param N target number of particles
 //' @param eta upper bound on the ratio between the weights. Must be >=4.
-//' @return A list with two elements: new weights and indices 
+//'        If eta=Inf then only thinnig is performed, requiring the number of weights to be at least N.
+//' @param normalise Flag for controlling if the returned weights should
+//'        be normalised. If TRUE (default) then the sum of the returned
+//'        weights will sum to N. If FALSE then the returned weights have
+//'        the same sum as the original weights (within the numerical precision).
+//' @param checks Flag controlling if checks on the input and the result should be performed. Default TRUE.
+//' @return A list with two elements: new weights and indices
 //' of the ancestors of the new particles. The weights are normalised to add up to N.
 //'
 //' @references
-//' A Gandy and F. D-H Lau. The chopthin algorithm for 
+//' A Gandy and F. D-H Lau. The chopthin algorithm for
 //' resampling. arXiv:1502.07532 [stat.CO], 2015
-//' 
+//'
 //' @examples
 //' chopthin(runif(10),N=10)
 //' chopthin(runif(10),N=20,4)
@@ -30,10 +36,13 @@ inline double myrunif(){return unif_rand();}
 //' chopthin(runif(10),N=1)
 //' @export
 // [[Rcpp::export]]
-List chopthin(std::vector<double>& w, int N, double eta=5.828427){
+List chopthin(std::vector<double>& w, int N, double eta=5.828427, bool normalise=true, bool checks=true){
   std::vector<double> wres(N);
   std::vector<int> ires(N);
-  chopthin_internal(w,N,wres,ires,eta);
+  if (checks)
+    chopthin_internal<true>(w,N,wres,ires,eta,normalise);
+  else
+    chopthin_internal<false>(w,N,wres,ires,eta,normalise);
   List res;
   res["weights"]=NumericVector(wres.begin(),wres.end());
   res["indices"]=IntegerVector(ires.begin(),ires.end());
